@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2009 Luca Falavigna
+# Copyright (C) 2007-2010 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -22,11 +22,9 @@ from ConfigParser import ConfigParser
 
 gettext.install("debomatic")
 
-class Semaphores:
-    pass
-
 Options = ConfigParser()
 acceptedqueue = list()
 packagequeue = dict()
-sema = Semaphores()
+buildlock = None
+pbuilderlock = dict()
 running = True
