@@ -1,6 +1,7 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2009 Luca Falavigna
+# Copyright (C) 2007-2010 Luca Falavigna
+# Copyright (C) 2010 Alessio Treglia
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -19,22 +20,29 @@
 
 import os
 import sys
-import threading
 from re import findall
-from Debomatic import gpg
-from Debomatic import locks
-from Debomatic import packages
-from Debomatic import pbuilder
-from Debomatic import Options
-from Debomatic import packagequeue
-from Debomatic import modules
+from Debomatic import gpg, locks, packages, pbuilder, Options, packagequeue, modules
 
 def build_process():
     directory = Options.get('default', 'packagedir')
     configdir = Options.get('default', 'configdir')
+    try:
+        blfile = Options.get('default', 'distblacklist')
+    except:
+        blfile = None
+    distblacklist = []
+    if blfile and os.path.exists(blfile):
+        fd = os.open(blfile, os.O_RDONLY)
+        data = os.read(fd, os.fstat(fd).st_size)
+        os.close(fd)
+        distblacklist = data.split()
     package = packages.select_package(directory)
     if package:
         distopts = parse_distribution_options(directory, configdir, package)
+        if distopts['distribution'] in distblacklist:
+            print _('Distribution %s is disabled' % distopts['distribution'])
+            packages.rm_package(package)
+            sys.exit(-1)
         try:
             fd = os.open(os.path.join(directory, package), os.O_RDONLY)
         except:
@@ -50,7 +58,7 @@ def build_process():
         packagequeue[package].append(os.path.join(directory, package))
         os.close(fd)
         try:
-            gpg.check_changes_signature(os.path.join(directory, package))
+            uploader = gpg.check_changes_signature(os.path.join(directory, package))
         except RuntimeError, error:
             packages.rm_package(package)
             print error
@@ -63,14 +71,14 @@ def build_process():
             packages.del_package(package)
             print error
             sys.exit(-1)
-        build_package(directory, os.path.join(configdir, distopts['distribution']), distdir, package, distopts)
+        build_package(directory, os.path.join(configdir, distopts['distribution']), distdir, package, uploader, distopts)
 
 def parse_distribution_options(packagedir, configdir, package):
     options = dict()
     try:
         fd = os.open(os.path.join(packagedir, package), os.O_RDONLY)
     except:
-        print 'Unable to open %s' % os.path.join(packagedir, package)
+        print _('Unable to open %s') % os.path.join(packagedir, package)
         packages.del_package(package)
         sys.exit(-1)
     try:
@@ -113,9 +121,11 @@ def parse_distribution_options(packagedir, configdir, package):
         sys.exit(-1)
     return options
 
-def build_package(directory, configfile, distdir, package, distopts):
+def build_package(directory, configfile, distdir, package, uploader, distopts):
     mod_sys = modules.Module()
-    if not locks.buildlock_acquire():
+    try:
+        locks.buildlock_acquire()
+    except:
         packages.del_package(package)
         sys.exit(-1)
     dscfile = None
@@ -130,17 +140,23 @@ def build_package(directory, configfile, distdir, package, distopts):
         packageversion = None
     if not os.path.exists(os.path.join(distdir, 'pool', packageversion)):
         os.mkdir(os.path.join(distdir, 'pool', packageversion))
+    uploader_email = ''
+    if uploader:
+        uploader_email = uploader[1]
     mod_sys.execute_hook('pre_build', { 'directory': distdir, 'package': packageversion, \
-              'cfg': configfile, 'distribution': distopts['distribution'], 'dsc': dscfile[0]})
+                         'uploader' : uploader_email, 'cfg': configfile, \
+                         'distribution': distopts['distribution'], 'dsc': dscfile[0]})
     base = '--basepath' if Options.get('default', 'builder') == 'cowbuilder' else '--basetgz'
     os.system('%(builder)s --build %(basetype)s %(directory)s/%(distribution)s \
-              --override-config --configfile %(cfg)s --logfile %(directory)s/pool/%(package)s/%(package)s.buildlog \
+              --override-config  --logfile %(directory)s/pool/%(package)s/%(package)s.buildlog \
               --buildplace %(directory)s/build --buildresult %(directory)s/pool/%(package)s \
-              --aptcache %(directory)s/aptcache %(dsc)s >/dev/null 2>&1' \
+              --aptcache %(directory)s/aptcache %(debopts)s --configfile %(cfg)s %(dsc)s >/dev/null 2>&1' \
               % { 'builder': Options.get('default', 'builder'), 'basetype': base, 'directory': distdir, \
-              'package': packageversion, 'cfg': configfile, 'distribution': distopts['distribution'], 'dsc': dscfile[0]})
+              'package': packageversion, 'cfg': configfile, 'distribution': distopts['distribution'], \
+              'debopts': packages.get_compression(package), 'dsc': dscfile[0]})
     mod_sys.execute_hook('post_build', { 'directory': distdir, 'package': packageversion, \
-              'cfg': configfile, 'distribution': distopts['distribution'], 'dsc': dscfile[0]})
+                         'uploader' : uploader_email, 'cfg': configfile, \
+                         'distribution': distopts['distribution'], 'dsc': dscfile[0]})
     packages.rm_package(package)
     locks.buildlock_release()
 
