@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2009 Luca Falavigna
+# Copyright (C) 2007-2010 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -24,11 +24,7 @@ from fcntl import lockf, LOCK_EX, LOCK_NB
 from getopt import getopt, GetoptError
 from signal import pause
 from time import sleep
-from Debomatic import build
-from Debomatic import commands
-from Debomatic import Options
-from Debomatic import modules
-from Debomatic import running
+from Debomatic import build, commands, Options, modules, running
 
 def main():
     conffile = None
@@ -99,23 +95,25 @@ def parse_default_options(conffile):
             sys.exit(-1)
 
 try:
-    import os
     import pyinotify
-    from re import findall
 
     class PE(pyinotify.ProcessEvent):
         def process_IN_CLOSE_WRITE(self, event):
-            if findall('source.changes$', event.name):
+            if event.name.endswith('source.changes'):
                 threading.Thread(None, build.build_process).start()
-            elif findall('commands$', event.name):
+            elif event.name.endswith('commands'):
                 threading.Thread(None, commands.process_commands).start()
 
     def launcher_inotify():
         if Options.getint('default', 'inotify'):
             wm = pyinotify.WatchManager()
-            notifier = pyinotify.Notifier(wm, PE())
+            notifier = pyinotify.Notifier(wm, PE(), timeout=1000)
             wm.add_watch(Options.get('default', 'packagedir'), pyinotify.IN_CLOSE_WRITE, rec=True)
-            notifier.loop(callback=exit_routine)
+            while exit_routine():
+                notifier.process_events()
+                if notifier.check_events():
+                    notifier.read_events()
+            notifier.stop()
 except:
     def launcher_inotify():
         pass
@@ -135,11 +133,8 @@ def launcher():
         print _('\nWaiting for threads to finish, it could take a while...')
         exit_routine(exiting=True)
 
-def exit_routine(self=None, exiting=False):
+def exit_routine(exiting=False):
     global running
     if exiting:
         running = False
-        return
-    if not running:
-        sys.exit(0)
     return running
