@@ -1,6 +1,7 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2009 Luca Falavigna
+# Copyright (C) 2007-2010 Luca Falavigna
+# Copyright (C) 2010 Alessio Treglia
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -21,8 +22,7 @@ import os
 import sys
 from re import findall, split
 from urllib2 import Request, urlopen
-from Debomatic import acceptedqueue
-from Debomatic import packagequeue
+from Debomatic import acceptedqueue, packagequeue
 
 def select_package(directory):
     package = None
@@ -103,3 +103,13 @@ def fetch_missing_files(package, files, packagedir, distopts):
             packagequeue[package].append(os.path.join(packagedir, entry))
     os.close(fd)
 
+def get_compression(package):
+    ext = {'.gz': 'gzip', '.bz2': 'bzip2', '.lzma': 'lzma', '.xz': 'xz'}
+    for pkgfile in packagequeue[package]:
+        if os.path.exists(pkgfile):
+            if findall('(.*\.debian\..*)', pkgfile):
+                try:
+                    return "--debbuildopts -Z%s" % ext[os.path.splitext(pkgfile)[1]]
+                except:
+                    pass
+    return ""
