@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2009 Luca Falavigna
+# Copyright (C) 2007-2010 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -18,17 +18,17 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 import os
-import sys
 from hashlib import sha256
 from time import strftime
-from urllib import urlopen
-from Debomatic import locks
-from Debomatic import Options
+from urllib2 import urlopen
+from Debomatic import locks, Options
 
 def setup_pbuilder(directory, configdir, distopts):
     if not os.path.exists(os.path.join(directory)):
         os.mkdir(os.path.join(directory))
-    if not locks.pbuilderlock_acquire(distopts['distribution']):
+    try:
+        locks.pbuilderlock_acquire(distopts['distribution'])
+    except RuntimeError:
         raise RuntimeError
     try:
         needs_update(directory, distopts['mirror'], distopts['distribution'])
@@ -36,6 +36,7 @@ def setup_pbuilder(directory, configdir, distopts):
         try:
             prepare_pbuilder(result.args[0], directory, configdir, distopts)
         except RuntimeError, error:
+            locks.pbuilderlock_release(distopts['distribution'])
             raise error
         if not os.path.exists(os.path.join(directory, 'gpg')):
             os.mkdir(os.path.join(directory, 'gpg'))
@@ -60,6 +61,8 @@ def needs_update(directory, mirror, distribution):
         fd = os.open(gpgfile, os.O_RDONLY)
     except OSError:
         raise RuntimeError('create')
+    if os.path.exists(os.path.join(directory, 'gpg', 'alwaysupdate')):
+        raise RuntimeError('update')
     try:
         remote = urlopen('%s/dists/%s/Release.gpg' % (mirror, distribution)).read()
     except:
@@ -82,11 +85,10 @@ def prepare_pbuilder(cmd, directory, configdir, distopts):
         os.mkdir(os.path.join(directory, 'logs'))
     base = '--basepath' if Options.get('default', 'builder') == 'cowbuilder' else '--basetgz'
     if (os.system('%(builder)s --%(cmd)s %(basetype)s %(directory)s/%(distribution)s \
-                  --override-config --configfile %(cfg)s --buildplace %(directory)s/build \
-                  --aptcache "%(directory)s/aptcache" --logfile %(directory)s/logs/%(cmd)s.%(now)s >/dev/null 2>&1' \
+                  --override-config --buildplace %(directory)s/build --aptcache "%(directory)s/aptcache" \
+                  --logfile %(directory)s/logs/%(cmd)s.%(now)s --configfile %(cfg)s >/dev/null 2>&1' \
                   % {'builder': Options.get('default', 'builder'), 'cmd': cmd, 'directory': directory, 'basetype': base, \
                      'distribution': distopts['distribution'], 'cfg': os.path.join(configdir, distopts['distribution']), \
                      'now': strftime('%Y%m%d_%H%M')})):
-        locks.pbuilderlock_release(distopts['distribution'])
         raise RuntimeError(_('%(builder)s %(cmd)s failed') % {'builder':Options.get('default', 'builder'), 'cmd':cmd})
 
